#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bimap
version:              0.5.0
visibility:           public
id:                   bimap-0.5.0-KlVEAz4vLia5xuTujxvlsk
key:                  bimap-0.5.0-KlVEAz4vLia5xuTujxvlsk
license:              BSD-3-Clause
copyright:            Stuart Cook and contributors 2008, Joel Williamson 2015
maintainer:           Joel Williamson <joel@joelwilliamson.ca>
author:               Stuart Cook and contributors 2008, Joel Williamson 2015
homepage:             https://github.com/joelwilliamson/bimap
synopsis:             Bidirectional mapping between two key types
description:
    A data structure representing a bidirectional mapping between two
    key types. Each value in the bimap is associated with exactly one
    value of the opposite type.

category:             Data
abi:                  8e9310d728e425a30c75968b164eb41e
exposed:              True
exposed-modules:      Data.Bimap
hidden-modules:       Data.BimapExt
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bimap-0.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bimap-0.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bimap-0.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bimap
hs-libraries:         HSbimap-0.5.0-KlVEAz4vLia5xuTujxvlsk
depends:
    base-4.18.2.1 containers-0.6.7 deepseq-1.4.8.1 exceptions-0.10.7

haddock-interfaces:   /usr/share/doc/haskell-bimap/html/bimap.haddock
haddock-html:         /usr/share/doc/haskell-bimap/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

